@@ -342,10 +342,9 @@ class Cursor(common.DBAPICursor):
             self.fetch_batch()
             if len(self._batch) == 0:
                 return None
-        self._rownumber += len(self._batch)
-        _logger.info("Row Number: ", self._rownumber)
-        _logger.info("lenght of batch: ", len(self._batch))
-        if self._rownumber <= 1000:
+        _logger.info("lenght of batch: ", self._batch)
+        self.rows_count += len(self._batch)
+        if self.rows_count <= 1000:
             _logger.info("e6x - Breaking the loop after 1000 e6x - fetch many records")
             return self._batch
         # batchRecords = self._batch
@@ -378,7 +377,7 @@ class Error(Exception):
 
 
 if __name__ == '__main__':
-    connection = connect(host="44.201.53.50",
+    connection = connect(host="44.200.35.172",
                          port=9000,
                          scheme="e6xdb",
                          username="admin",
